# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .config_management_service_pb2 import GetTimeModelRequest, GetTimeModelResponse, SetTimeModelRequest, SetTimeModelResponse, TimeModel
from .config_management_service_pb2_grpc import ConfigManagementServiceStub
from .metering_report_service_pb2 import ApplicationMeteringReport, GetMeteringReportRequest, GetMeteringReportResponse, ParticipantMeteringReport
from .metering_report_service_pb2_grpc import MeteringReportServiceStub
from .package_management_service_pb2 import ListKnownPackagesRequest, ListKnownPackagesResponse, PackageDetails, UploadDarFileRequest, UploadDarFileResponse
from .package_management_service_pb2_grpc import PackageManagementServiceStub
from .participant_pruning_service_pb2 import PruneRequest, PruneResponse
from .participant_pruning_service_pb2_grpc import ParticipantPruningServiceStub
from .party_management_service_pb2 import AllocatePartyRequest, AllocatePartyResponse, GetParticipantIdRequest, GetParticipantIdResponse, GetPartiesRequest, GetPartiesResponse, ListKnownPartiesRequest, ListKnownPartiesResponse, PartyDetails
from .party_management_service_pb2_grpc import PartyManagementServiceStub
from .user_management_service_pb2 import CreateUserRequest, CreateUserResponse, DeleteUserRequest, DeleteUserResponse, GetUserRequest, GetUserResponse, GrantUserRightsRequest, GrantUserRightsResponse, ListUserRightsRequest, ListUserRightsResponse, ListUsersRequest, ListUsersResponse, RevokeUserRightsRequest, RevokeUserRightsResponse, Right, User
from .user_management_service_pb2_grpc import UserManagementServiceStub

__all__ = [
    "AllocatePartyRequest",
    "AllocatePartyResponse",
    "ApplicationMeteringReport",
    "ConfigManagementServiceStub",
    "CreateUserRequest",
    "CreateUserResponse",
    "DeleteUserRequest",
    "DeleteUserResponse",
    "GetMeteringReportRequest",
    "GetMeteringReportResponse",
    "GetParticipantIdRequest",
    "GetParticipantIdResponse",
    "GetPartiesRequest",
    "GetPartiesResponse",
    "GetTimeModelRequest",
    "GetTimeModelResponse",
    "GetUserRequest",
    "GetUserResponse",
    "GrantUserRightsRequest",
    "GrantUserRightsResponse",
    "ListKnownPackagesRequest",
    "ListKnownPackagesResponse",
    "ListKnownPartiesRequest",
    "ListKnownPartiesResponse",
    "ListUserRightsRequest",
    "ListUserRightsResponse",
    "ListUsersRequest",
    "ListUsersResponse",
    "MeteringReportServiceStub",
    "PackageDetails",
    "PackageManagementServiceStub",
    "ParticipantMeteringReport",
    "ParticipantPruningServiceStub",
    "PartyDetails",
    "PartyManagementServiceStub",
    "PruneRequest",
    "PruneResponse",
    "RevokeUserRightsRequest",
    "RevokeUserRightsResponse",
    "Right",
    "SetTimeModelRequest",
    "SetTimeModelResponse",
    "TimeModel",
    "UploadDarFileRequest",
    "UploadDarFileResponse",
    "User",
    "UserManagementServiceStub",
]



# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/transaction_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/com/daml/ledger/api/v1/transaction_filter.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\"com/daml/ledger/api/v1/value.proto\"\xe0\x01\n\x11TransactionFilter\x12g\n\x10\x66ilters_by_party\x18\x01 \x03(\x0b\x32=.com.daml.ledger.api.v1.TransactionFilter.FiltersByPartyEntryR\x0e\x66iltersByParty\x1a\x62\n\x13\x46iltersByPartyEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v1.FiltersR\x05value:\x02\x38\x01\"Q\n\x07\x46ilters\x12\x46\n\tinclusive\x18\x01 \x01(\x0b\x32(.com.daml.ledger.api.v1.InclusiveFiltersR\tinclusive\"Y\n\x10InclusiveFilters\x12\x45\n\x0ctemplate_ids\x18\x01 \x03(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\x0btemplateIdsB\x95\x01\n\x16\x63om.daml.ledger.api.v1B\x1bTransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v7/go/api/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3')



_TRANSACTIONFILTER = DESCRIPTOR.message_types_by_name['TransactionFilter']
_TRANSACTIONFILTER_FILTERSBYPARTYENTRY = _TRANSACTIONFILTER.nested_types_by_name['FiltersByPartyEntry']
_FILTERS = DESCRIPTOR.message_types_by_name['Filters']
_INCLUSIVEFILTERS = DESCRIPTOR.message_types_by_name['InclusiveFilters']
TransactionFilter = _reflection.GeneratedProtocolMessageType('TransactionFilter', (_message.Message,), {

  'FiltersByPartyEntry' : _reflection.GeneratedProtocolMessageType('FiltersByPartyEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSACTIONFILTER_FILTERSBYPARTYENTRY,
    '__module__' : 'com.daml.ledger.api.v1.transaction_filter_pb2'
    # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.TransactionFilter.FiltersByPartyEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSACTIONFILTER,
  '__module__' : 'com.daml.ledger.api.v1.transaction_filter_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.TransactionFilter)
  })
_sym_db.RegisterMessage(TransactionFilter)
_sym_db.RegisterMessage(TransactionFilter.FiltersByPartyEntry)

Filters = _reflection.GeneratedProtocolMessageType('Filters', (_message.Message,), {
  'DESCRIPTOR' : _FILTERS,
  '__module__' : 'com.daml.ledger.api.v1.transaction_filter_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Filters)
  })
_sym_db.RegisterMessage(Filters)

InclusiveFilters = _reflection.GeneratedProtocolMessageType('InclusiveFilters', (_message.Message,), {
  'DESCRIPTOR' : _INCLUSIVEFILTERS,
  '__module__' : 'com.daml.ledger.api.v1.transaction_filter_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.InclusiveFilters)
  })
_sym_db.RegisterMessage(InclusiveFilters)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.daml.ledger.api.v1B\033TransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v7/go/api/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1'
  _TRANSACTIONFILTER_FILTERSBYPARTYENTRY._options = None
  _TRANSACTIONFILTER_FILTERSBYPARTYENTRY._serialized_options = b'8\001'
  _TRANSACTIONFILTER._serialized_start=112
  _TRANSACTIONFILTER._serialized_end=336
  _TRANSACTIONFILTER_FILTERSBYPARTYENTRY._serialized_start=238
  _TRANSACTIONFILTER_FILTERSBYPARTYENTRY._serialized_end=336
  _FILTERS._serialized_start=338
  _FILTERS._serialized_end=419
  _INCLUSIVEFILTERS._serialized_start=421
  _INCLUSIVEFILTERS._serialized_end=510
# @@protoc_insertion_point(module_scope)
